import QtQuick 2.0

import org.kde.plasma.private.mobileshell 1.0 as MobileShell

Item {
    id: root

    function isDesktopView() {
        return MobileShell.MobileShellSettings.isDesktopView
    }

    function virtualKeyboardShown() {
        for(let i = 0; i < workspace.clientList().length; i++) {
            let client = workspace.clientList()[i];

            // windowType NETWM::WindowType::Utility == 8
            if (client.normalWindow == false && client.windowType == 8
                && client.specialWindow == false && client.caption == "" && client.wantsInput == false)
                return true;
        }
        return false;
    }

    function maximize(client) {
        client.clientStepUserMovedResized.connect((client) => {
            if (!isDesktopView())
                client.setMaximize(true, true);
        });

        client.clientFinishUserMovedResized.connect((client) => {
            if (!isDesktopView())
                client.setMaximize(true, true);
        });

        client.clientMaximizedStateChanged.connect((client, h, v) => {
            if (!isDesktopView() && (!h || !v))
                client.setMaximize(true, true);
        });

        client.geometryChanged.connect(() => {
            if (!isDesktopView()) {
                if (client.geometry.x > 50 || client.geometry.y > 50)
                    workspace.slotWindowMaximize(client);

                if (!virtualKeyboardShown()) {
                    workspace.slotWindowExpandHorizontal(client);
                    workspace.slotWindowExpandVertical(client);
                }
            }
        });

        workspace.slotWindowExpandHorizontal(client);
        workspace.slotWindowExpandVertical(client);
    }

    function isNeedMaximize(client) {
        return client.caption.indexOf(" – Chromium") >= 0
               || (client.caption == "Gallery")
               || (client.caption == "Галерея")
               || (client.caption.indexOf("Evolution") >= 0);
    }

    Connections {
        target: workspace

        function onClientAdded(client) {
            if (!isDesktopView() && isNeedMaximize(client))
                root.maximize(client);
        }
    }
}
